pygeai.tests.snippets.evaluation package
========================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pygeai.tests.snippets.evaluation.dataset
   pygeai.tests.snippets.evaluation.plan
   pygeai.tests.snippets.evaluation.result

Module contents
---------------

.. automodule:: pygeai.tests.snippets.evaluation
   :members:
   :show-inheritance:
   :undoc-members:
